summaryrefslogtreecommitdiffstats
path: root/sys/dev/drm/radeon_mem.c
diff options
context:
space:
mode:
authoranholt <anholt@FreeBSD.org>2003-09-09 00:24:31 +0000
committeranholt <anholt@FreeBSD.org>2003-09-09 00:24:31 +0000
commit6b432655804f704cb7d1fa3e6317548be1cfc164 (patch)
treedcab6440d210d4a1026afdd0cbbd73f19c8c6dd3 /sys/dev/drm/radeon_mem.c
parent9eac29c0b915eec97e0a9539816cae19448bd20d (diff)
downloadFreeBSD-src-6b432655804f704cb7d1fa3e6317548be1cfc164.zip
FreeBSD-src-6b432655804f704cb7d1fa3e6317548be1cfc164.tar.gz
Merge from DRI CVS. Includes newly ported SiS 300/305/540/630/730 driver and
updates to allow system memory to be used for textures on PCI Radeons. Sponsored by: LinuxFund
Diffstat (limited to 'sys/dev/drm/radeon_mem.c')
-rw-r--r--sys/dev/drm/radeon_mem.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/sys/dev/drm/radeon_mem.c b/sys/dev/drm/radeon_mem.c
index 62d57fd..ed72dd6 100644
--- a/sys/dev/drm/radeon_mem.c
+++ b/sys/dev/drm/radeon_mem.c
@@ -1,4 +1,4 @@
/* radeon_mem.c -- Simple agp/fb memory manager for radeon -*- linux-c -*-
*
* Copyright (C) The Weather Channel, Inc. 2002. All Rights Reserved.
*
@@ -39,7 +39,7 @@ __FBSDID("$FreeBSD$");
#include "dev/drm/radeon_drm.h"
#include "dev/drm/radeon_drv.h"
/* Very simple allocator for agp memory, working on a static range
* already mapped into each client's address space.
*/
@@ -216,8 +216,8 @@ static struct mem_block **get_heap( drm_radeon_private_t *dev_priv,
int region )
{
switch( region ) {
- case RADEON_MEM_REGION_AGP:
- return &dev_priv->agp_heap;
+ case RADEON_MEM_REGION_GART:
+ return &dev_priv->gart_heap;
case RADEON_MEM_REGION_FB:
return &dev_priv->fb_heap;
default:
@@ -1,4 +1,4 @@
-/* radeon_mem.c -- Simple agp/fb memory manager for radeon -*- linux-c -*-
+/* radeon_mem.c -- Simple GART/fb memory manager for radeon -*- linux-c -*-
*
* Copyright (C) The Weather Channel, Inc. 2002. All Rights Reserved.
@@ -39,7 +39,7 @@ __FBSDID("$FreeBSD$");
#include "dev/drm/radeon_drm.h"
#include "dev/drm/radeon_drv.h"
-/* Very simple allocator for agp memory, working on a static range
+/* Very simple allocator for GART memory, working on a static range
* already mapped into each client's address space.
*/
OpenPOWER on IntegriCloud